module RefinementSubstitutions where

f :: [Integer] -> Integer
f = _

g :: [Integer] -> Integer
g = _ 0

j :: a -> a
j a = _
